# Additional Products
Additional products complement SAP LeanIX Application Portfolio Management, the base product, by providing advanced features and capabilities.
  * [SAP LeanIX Technology Risk and Compliance](https://help.sap.com/docs/leanix/ea/sap-leanix-technology-risk-and-compliance?locale=en-US&state=PRODUCTION&version=CLOUD "Get an overview of SAP LeanIX Technology Risk and Compliance, with links to detailed guides for managing obsolescence risk, optimizing technology usage, and enforcing tech standards across your IT landscape."): This product helps you discover the infrastructure layer in your application landscape and manage obsolescence risks and technology standards. This ensures operational stability and relevance for your technology stack.
  * [SAP LeanIX Architecture and Road Map Planning](https://help.sap.com/docs/leanix/ea/sap-leanix-architecture-and-road-map-planning?locale=en-US&state=PRODUCTION&version=CLOUD "The SAP LeanIX Architecture and Road Map Planning enhances SAP LeanIX Application Portfolio Management by offering advanced features for seamless planning and execution of transformation initiatives in enterprise architecture management."): This product provides advanced features for planning your target architecture, allowing you to visualize the impacts of planned transformations and implement and monitor transformation initiatives.


YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
